@@ -459,10 +459,9 @@ def interceptor_db_execute(fn, *args, **kwargs):
     except Exception as e:
         interceptor_step_error(e)
     finally:
-        datas = [ctx.lctx.get('dbc', ''), query]
+        datas = [ctx.lctx.get('dbc', ''), query, str(self.rowcount)]
         ctx.elapsed = DateUtil.nowSystem() - start_time
-        async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
-                               datas)
+        async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx, datas)
         count = self.rowcount
         if count > -1:
             desc = '{0}: {1}'.format('Fetch count', count)
